@@ -1,9 +1,14 @@
 setMethod("display", signature(object = "lm"),
-    function(object, digits=2)
+    function(object, digits=2, detail=FALSE)
     {
     call <- object$call
     summ <- summary (object)
-    coef <- summ$coef[,,drop=FALSE]
+    if(detail){
+      coef <- summ$coef[,,drop=FALSE]
+    }
+    else{
+      coef <- summ$coef[,1:2,drop=FALSE]
+    }
     dimnames(coef)[[2]][1:2] <- c("coef.est","coef.se")
     n <- summ$df[1] + summ$df[2]
     k <- summ$df[1]
@@ -19,14 +24,20 @@ setMethod("display", signature(object = "lm"),
 
 
 setMethod("display", signature(object = "bayesglm"),
-    function(object, digits=2)
+    function(object, digits=2, detail=FALSE)
     {
     call <- object$call
     summ <- summary(object, dispersion = object$dispersion)
-    coef <- summ$coefficients
-#    rownames(coef) <- names( object$coefficients )          ## M
+    if(detail){
+      coef <- summ$coefficients
+      coef[ rownames( coef ) %in% rownames( summ$coef[, , drop = FALSE]) , ] <- summ$coef[ , , drop = FALSE ] 
+    }
+    else{
+      coef <- matrix( NA, length( object$coefficients ),2 )
+      rownames(coef) <- names( object$coefficients )          ## M
+      coef[ rownames( coef ) %in% rownames( summ$coef[, 1:2, drop = FALSE]) , ] <- summ$coef[ , 1:2, drop = FALSE ]  ## M
+    }
     dimnames(coef)[[2]][1:2] <- c( "coef.est", "coef.se")
-    coef[ rownames( coef ) %in% rownames( summ$coef[, , drop = FALSE]) , ] <- summ$coef[ , , drop = FALSE ]  ## M
     #n <- summ$df[1] + summ$df[2]
     n <- summ$df.residual
     k <- summ$df[1]
@@ -56,10 +67,16 @@ setMethod("display", signature(object = "bayesglm.h"),
     {
     call <- object$call
     summ <- summary(object, dispersion = object$dispersion)
-    coef <- matrix(NA, length(object$coefficients), 2)
-    rownames(coef) <- names(object$coefficients)
-    dimnames(coef)[[2]] <- c("coef.est", "coef.se")
-    coef[rownames(coef) %in% rownames(summ$coef[, 1:2, drop = FALSE]), ] <- summ$coef[, 1:2, drop = FALSE]
+    if(detail){
+      coef <- summ$coefficients
+      coef[ rownames( coef ) %in% rownames( summ$coef[, , drop = FALSE]) , ] <- summ$coef[ , , drop = FALSE ] 
+    }
+    else{
+      coef <- matrix( NA, length( object$coefficients ),2 )
+      rownames(coef) <- names( object$coefficients )          ## M
+      coef[ rownames( coef ) %in% rownames( summ$coef[, 1:2, drop = FALSE]) , ] <- summ$coef[ , 1:2, drop = FALSE ]  ## M
+    }
+    dimnames(coef)[[2]][1:2] <- c( "coef.est", "coef.se")
     #n <- summ$df[1] + summ$df[2]
     n <- summ$df.residual
     k <- summ$df[1]
@@ -97,11 +114,16 @@ setMethod("display", signature(object = "bayesglm.h"),
 
 
 setMethod("display", signature(object = "glm"),
-    function(object, digits=2)
+    function(object, digits=2, detail=FALSE)
     {
     call <- object$call
     summ <- summary(object, dispersion = object$dispersion)
-    coef <- summ$coef[, , drop = FALSE]
+    if(detail){
+      coef <- summ$coef[, , drop = FALSE]
+    }
+    else{
+      coef <- summ$coef[, 1:2, drop = FALSE]
+    }
     dimnames(coef)[[2]][1:2] <- c("coef.est", "coef.se")
     n <- summ$df[1] + summ$df[2]
     k <- summ$df[1]
@@ -170,7 +192,7 @@ setMethod("display", signature(object = "glm"),
 
 
 setMethod("display", signature(object = "mer"),
-    function(object, digits=2)
+    function(object, digits=2, detail=FALSE)
     {
     call <- object@call
     print (call)
@@ -194,7 +216,12 @@ setMethod("display", signature(object = "mer"),
         coefs <- cbind(coefs, `t value` = stat)
       }
     dimnames(coefs)[[2]][1:2] <- c("coef.est", "coef.se")
-    pfround (coefs, digits)
+      if(detail){
+        pfround (coefs, digits)
+      }
+      else{
+        pfround(coefs[,1:2], digits)
+      }
     }
     cat("\nError terms:\n")
     vc <- as.matrix.VarCorr (VarCorr (object), useScale=useScale, digits)
@@ -223,11 +250,16 @@ setMethod("display", signature(object = "mer"),
 
 
 setMethod("display", signature(object = "polr"),
-    function(object, digits=2)
+    function(object, digits=2, detail=FALSE)
     {
     call <- object$call
     summ <- summary(object)
-    coef <- summ$coef[, , drop = FALSE]
+    if(detail){
+      coef <- summ$coef[, , drop = FALSE]
+    }
+    else{
+      coef <- summ$coef[, 1:2, drop = FALSE]
+    }
     dimnames(coef)[[2]][1:2] <- c("coef.est", "coef.se")
     n <- summ$n  
     k <- nrow (coef)
